package com.poststats.golf.rs.api;

import com.poststats.golf.rs.api.model.Course;
import com.poststats.golf.rs.api.model.CourseNine;
import com.poststats.golf.rs.api.model.CourseTee;

import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.responses.ApiResponse;
import io.swagger.v3.oas.annotations.responses.ApiResponses;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.constraints.NotNull;
import jakarta.validation.constraints.Positive;
import jakarta.ws.rs.GET;
import jakarta.ws.rs.Path;
import jakarta.ws.rs.PathParam;
import jakarta.ws.rs.Produces;

/**
 * @author brian.long@poststats.com
 */
@Path("/golf/course/{courseId:[0-9]+}")
@Tag(name = "Course API")
@ApiResponses({
		@ApiResponse(responseCode = "200", description = "Success"),
		@ApiResponse(responseCode = "404", description = "A golf course with the specified ID could not be found")
})
public interface CourseApi {

	@GET
	@Produces(Constants.V1_JSON)
	@Operation(
			summary = "Retrieves meta-data about a course.",
			description = "Retreives name, location, and other direct meta-data about the specified course."
	)
	Course get(@Parameter(description = "A unique identifier for a golf course")
	@NotNull @Positive @PathParam("courseId") int courseId);

	@GET
	@Path("/nine/byName/{name}")
	@Produces(Constants.V1_JSON)
	@Operation(summary = "Retrieves meta-data about a course nine.")
	CourseNine getNine(@Parameter(description = "A unique identifier for a golf course")
	@NotNull @Positive @PathParam("courseId") int courseId, @PathParam("name") String name);

	@GET
	@Path("/nine/{nineId:[0-9]+}")
	@Produces(Constants.V1_JSON)
	@Operation(summary = "Retrieves limited meta-data about a course nine.")
	CourseNine getNine(@Parameter(description = "A unique identifier for a golf course")
	@NotNull @Positive @PathParam("courseId") int courseId, @PathParam("nineId") long courseNineId);

	@GET
	@Path("/nine/byName/{name}")
	@Produces(Constants.V1_JSON)
	@Operation(summary = "Retrieves meta-data about a course tee.")
	CourseTee getTee(@Parameter(description = "A unique identifier for a golf course")
	@NotNull @Positive @PathParam("courseId") int courseId, @PathParam("name") String name);

	@GET
	@Path("/nine/{nineId:[0-9]+}")
	@Produces(Constants.V1_JSON)
	@Operation(summary = "Retrieves limited meta-data about a course tee.")
	CourseTee getTee(@Parameter(description = "A unique identifier for a golf course")
	@NotNull @Positive @PathParam("courseId") int courseId, @PathParam("teeId") long courseTeeId);

}
