package com.poststats.golf.rs.api.model;

import java.time.Year;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.poststats.rs.api.annotation.MapEntry;
import com.poststats.rs.api.model.BaseModel;

@JsonIgnoreProperties(ignoreUnknown = true)
public abstract class BaseCourse<ConcreteT extends BaseCourse<ConcreteT>> extends BaseModel<ConcreteT> {

	public enum Access {
		@JsonProperty("private")
		@MapEntry("private")
		Private,
		@JsonProperty("military")
		@MapEntry("military")
		Military,
		@JsonProperty("semi-private")
		@MapEntry("semi-private")
		SemiPrivate,
		@JsonProperty("public")
		@MapEntry("public")
		Public,
	}

	@JsonProperty
	@MapEntry("course")
	private String name;

	@JsonProperty
	@MapEntry("prefix")
	private String namePrefix;

	@JsonProperty
	@MapEntry
	private Access access;

	@JsonProperty
	@MapEntry
	private Year opened;

	@JsonProperty
	@MapEntry
	private String architect;

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getNamePrefix() {
		return namePrefix;
	}

	public void setNamePrefix(String namePrefix) {
		this.namePrefix = namePrefix;
	}

	public Access getAccess() {
		return access;
	}

	public void setAccess(Access access) {
		this.access = access;
	}

	public Year getOpened() {
		return opened;
	}

	public void setOpened(Year opened) {
		this.opened = opened;
	}

	public String getArchitect() {
		return architect;
	}

	public void setArchitect(String architect) {
		this.architect = architect;
	}

	public ConcreteT withName(String name) {
		this.name = name;
		return this.withThis();
	}

	public ConcreteT withNamePrefix(String prefix) {
		this.namePrefix = prefix;
		return this.withThis();
	}

	public ConcreteT withAccess(Access access) {
		this.access = access;
		return this.withThis();
	}

	public ConcreteT withOpened(Year opened) {
		this.opened = opened;
		return this.withThis();
	}

	public ConcreteT withArchitect(String architect) {
		this.architect = architect;
		return this.withThis();
	}

}
