package com.poststats.golf.rs.api.model;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.poststats.rs.api.annotation.MapEntry;
import com.poststats.rs.api.model.BaseModel;

/**
 * @author brian.long@poststats.com
 */
@JsonIgnoreProperties(ignoreUnknown = true)
public abstract class BaseEvent<ConcreteT extends BaseEvent<ConcreteT>> extends BaseModel<ConcreteT> {

	public enum EventType {
		@JsonProperty("outing")
		@MapEntry("outing")
		Outing,
		@JsonProperty("tourney")
		@MapEntry("tourney")
		Tourney,
		@JsonProperty("trip")
		@MapEntry("trip")
		Trip,
		@JsonProperty("league")
		@MapEntry("league")
		League
	}

	@JsonProperty(required = true)
	@MapEntry("event")
	private String name;

	@JsonProperty(required = true)
	@MapEntry
	private EventType type;

	@JsonProperty
	private boolean showPublic;

	@JsonProperty
	private String fuzzyLocation;

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public EventType getType() {
		return type;
	}

	public void setType(EventType type) {
		this.type = type;
	}

	public boolean isShowPublic() {
		return showPublic;
	}

	public void setShowPublic(boolean showPublic) {
		this.showPublic = showPublic;
	}

	public String getFuzzyLocation() {
		return fuzzyLocation;
	}

	public void setFuzzyLocation(String fuzzyLocation) {
		this.fuzzyLocation = fuzzyLocation;
	}

	public ConcreteT withName(String name) {
		this.name = name;
		return this.withThis();
	}

	public ConcreteT withType(EventType type) {
		this.type = type;
		return this.withThis();
	}

	public ConcreteT withShowPublic(boolean showPublic) {
		this.showPublic = showPublic;
		return this.withThis();
	}

	public ConcreteT withFuzzyLocation(String fuzzyLocation) {
		this.fuzzyLocation = fuzzyLocation;
		return this.withThis();
	}

}
