package com.poststats.golf.rs.api.model;

import java.time.LocalDate;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.poststats.rs.api.annotation.MapEntry;
import com.poststats.rs.api.model.BaseModel;

/**
 * @author brian.long@poststats.com
 */
@JsonIgnoreProperties(ignoreUnknown = true)
public abstract class BaseEventRound<ConcreteT extends BaseEventRound<ConcreteT>> extends BaseModel<ConcreteT> {

	public enum TeeFormat {
		@JsonProperty("straight")
		@MapEntry("straight")
		Straight,
		@JsonProperty("dual")
		@MapEntry("dual")
		Dual,
		@JsonProperty("shotgun-9")
		@MapEntry("shotgun-9")
		Shotgun9Hole,
		@JsonProperty("shotgun-18")
		@MapEntry("shotgun-18")
		Shotgun18Hole
	}

	@JsonProperty
	@MapEntry("round")
	private Short number;

	@JsonProperty
	@MapEntry("title")
	private String name;

	@JsonProperty
	@MapEntry
	private LocalDate date;

	@JsonProperty
	@MapEntry("teeFormatSID")
	private TeeFormat teeFormat;

	public Short getNumber() {
		return number;
	}

	public void setNumber(Short number) {
		this.number = number;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public LocalDate getDate() {
		return date;
	}

	public void setDate(LocalDate date) {
		this.date = date;
	}

	public TeeFormat getTeeFormat() {
		return teeFormat;
	}

	public void setTeeFormat(TeeFormat teeFormat) {
		this.teeFormat = teeFormat;
	}

	public ConcreteT withNumber(Short number) {
		this.number = number;
		return this.withThis();
	}

	public ConcreteT withName(String name) {
		this.name = name;
		return this.withThis();
	}

	public ConcreteT withDate(LocalDate date) {
		this.date = date;
		return this.withThis();
	}

	public ConcreteT withTeeFormat(TeeFormat teeFormat) {
		this.teeFormat = teeFormat;
		return this.withThis();
	}

}
