package com.poststats.golf.rs.api.model;

import java.time.LocalDate;
import java.time.OffsetDateTime;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.poststats.golf.rs.api.Constants;
import com.poststats.rs.api.annotation.MapCondition;
import com.poststats.rs.api.annotation.MapEntry;
import com.poststats.rs.api.model.Facility;
import com.poststats.rs.api.model.PeriodConstrainable;

@JsonIgnoreProperties(ignoreUnknown = true)
public class Course extends BaseCourse<Course> implements ReferenceableCourse, PeriodConstrainable<LocalDate> {

	@JsonProperty(required = true, access = JsonProperty.Access.READ_ONLY)
	@MapEntry("courseID")
	private int id;

	@JsonProperty
	@MapEntry("liveline")
	@MapCondition(rolesAllowed = {
			Constants.ADMIN_ROLE, "course"
	})
	private LocalDate liveline;

	@JsonProperty
	@MapEntry("deadline")
	@MapCondition(rolesAllowed = {
			Constants.ADMIN_ROLE, "course"
	})
	private LocalDate deadline;

	@JsonProperty(access = JsonProperty.Access.READ_ONLY)
	@MapEntry("created")
	@MapCondition(rolesAllowed = {
			Constants.ADMIN_ROLE, "course"
	})
	private OffsetDateTime created;

	@JsonProperty
	@MapEntry
	private Facility facility;

	@JsonProperty
	@MapEntry("facilityID")
	private Integer facilityId;

	@Override
	public int getId() {
		return id;
	}

	public void setId(int id) {
		this.id = id;
	}

	@Override
	public LocalDate getLiveline() {
		return liveline;
	}

	@Override
	public void setLiveline(LocalDate liveline) {
		this.liveline = liveline;
	}

	@Override
	public LocalDate getDeadline() {
		return deadline;
	}

	@Override
	public void setDeadline(LocalDate deadline) {
		this.deadline = deadline;
	}

	public OffsetDateTime getCreated() {
		return created;
	}

	public void setCreated(OffsetDateTime created) {
		this.created = created;
	}

	public Facility getFacility() {
		return facility;
	}

	public void setFacility(Facility facility) {
		this.facility = facility;
	}

	public Integer getFacilityId() {
		return facilityId;
	}

	public void setFacilityId(Integer facilityId) {
		this.facilityId = facilityId;
	}

	public Course withId(int id) {
		this.id = id;
		return this;
	}

	public Course withLiveline(LocalDate liveline) {
		this.liveline = liveline;
		return this;
	}

	public Course withDeadline(LocalDate deadline) {
		this.deadline = deadline;
		return this;
	}

	public Course withCreated(OffsetDateTime created) {
		this.created = created;
		return this;
	}

	public Course withFacility(Facility facility) {
		this.facility = facility;
		return this;
	}

	public Course withFacilityId(Integer facilityId) {
		this.facilityId = facilityId;
		return this;
	}

}
